==> dif-database-repository-2.3.0-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/DataConsentReview.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import pt.digitalis.dif.model.utils.AbstractBeanRelationsAttributes;

/**
 * DataConsentReview
 * Generated on ORM Generator
 * DIF build process for the Model layer
 *
 */
@SuppressWarnings("serial")
public class DataConsentReview extends AbstractBeanRelationsAttributes implements java.io.Serializable {

    /** DataConsentReview attributes enumeration */
    public static class Fields {
        /** id column */
        public static final String ID = "id";
        /** userId column */
        public static final String USERID = "userId";
        /** lastReviewDate column */
        public static final String LASTREVIEWDATE = "lastReviewDate";

	    /**
          * List of existing fields
	     *
	     * @return list of field names
	     */
        public static List<String> values() {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("userId");
            list.add("lastReviewDate");

            return list;
        }
    }

	/**
 	 * The Class Relations.
 	 */
	 public class Relations extends AbstractBeanRelationsAttributes.AbstractRelations {

        /**
         * Instantiates a new relations.
         *
         * @param currentPath
         *            the current path
         */
        public Relations(String currentPath)
        {
            super(currentPath);
        }
        /**
         * dataConsent relation.
         *
         * @return the dataConsent bean relations attributes.
         */
        public DataConsent.Relations dataConsent()
        {
			DataConsent c = new DataConsent();
            return c.new Relations(this.buildPath("dataConsent"));
        }
        
		/**
         * the ID path.
         *
         * @return the path
         */
        public String ID()
        {
            return buildPath(Fields.ID);
        }
		/**
         * the USERID path.
         *
         * @return the path
         */
        public String USERID()
        {
            return buildPath(Fields.USERID);
        }
		/**
         * the LASTREVIEWDATE path.
         *
         * @return the path
         */
        public String LASTREVIEWDATE()
        {
            return buildPath(Fields.LASTREVIEWDATE);
        }
    }
	
	/** The dummy obj. */
    private static DataConsentReview dummyObj = new DataConsentReview();

	/**
     * Get DataConsentReview Relations .
     *
     * @return the relations
     */
    public static Relations FK()
    {
        return dummyObj.new Relations(null);
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
     */
    protected Object getAttributeNoGraphNavigation(String attributeName) {

        if ("id".equalsIgnoreCase(attributeName))
            return id;
        if ("dataConsent".equalsIgnoreCase(attributeName))
            return dataConsent;
        if ("userId".equalsIgnoreCase(attributeName))
            return userId;
        if ("lastReviewDate".equalsIgnoreCase(attributeName))
            return lastReviewDate;

        return null;
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
     */
    @SuppressWarnings("all")
    public void setAttribute(String attributeName, Object attributeValue) {

        if ("id".equalsIgnoreCase(attributeName))
            id = (Long)attributeValue;
        if ("dataConsent".equalsIgnoreCase(attributeName))
            dataConsent = (DataConsent)attributeValue;
        if ("userId".equalsIgnoreCase(attributeName))
            userId = (String)attributeValue;
        if ("lastReviewDate".equalsIgnoreCase(attributeName))
            lastReviewDate = (Timestamp)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** dataConsent private attribute */
    private DataConsent dataConsent;

    /** userId private attribute */
    private String userId;

    /** lastReviewDate private attribute */
    private Timestamp lastReviewDate;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else {
            return value.toString().trim();
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public DataConsentReview() {
    }


    /**
     * full constructor
	 *
     * @param dataConsent
     * @param userId
     * @param lastReviewDate
     */
    public DataConsentReview(DataConsent dataConsent, String userId, Timestamp lastReviewDate) {
        this.dataConsent = dataConsent;
        this.userId = userId;
        this.lastReviewDate = lastReviewDate;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id
     *
     * @return DataConsentReview modified instance
     */
    public DataConsentReview setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * dataConsent getter method
     *
     * @return dataConsent method
     */
    public DataConsent getDataConsent() {
        return this.dataConsent;
    }
    
    /**       
     * dataConsent setter method
     *
     * @param dataConsent
     *
     * @return DataConsentReview modified instance
     */
    public DataConsentReview setDataConsent(DataConsent dataConsent) {
        this.dataConsent = dataConsent;
        
        return this;
    }
    /**       
     * userId getter method
     *
     * @return userId method
     */
    public String getUserId() {
        return this.userId;
    }
    
    /**       
     * userId setter method
     *
     * @param userId
     *
     * @return DataConsentReview modified instance
     */
    public DataConsentReview setUserId(String userId) {
        this.userId = userId;
        
        return this;
    }
    /**       
     * lastReviewDate getter method
     *
     * @return lastReviewDate method
     */
    public Timestamp getLastReviewDate() {
        return this.lastReviewDate;
    }
    
    /**       
     * lastReviewDate setter method
     *
     * @param lastReviewDate
     *
     * @return DataConsentReview modified instance
     */
    public DataConsentReview setLastReviewDate(Timestamp lastReviewDate) {
        this.lastReviewDate = lastReviewDate;
        
        return this;
    }

    /**
     * Creates a String representation of the DataConsentReview object
     *
     * @return the compiled String
     */
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("userId").append("='").append(getUserId()).append("' ");			
        buffer.append("lastReviewDate").append("='").append(getLastReviewDate()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the DataConsentReview object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(DataConsentReview other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("userId".equalsIgnoreCase(attributeName))
        	this.userId = attributeValue;

        if ("lastReviewDate".equalsIgnoreCase(attributeName))
            this.lastReviewDate = Timestamp.valueOf(attributeValue);

    }


}

==> dif-database-repository-2.3.4-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/DataConsentReview.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import pt.digitalis.dif.model.utils.AbstractBeanRelationsAttributes;

/**
 * DataConsentReview
 * Generated on ORM Generator
 * DIF build process for the Model layer
 *
 */
@SuppressWarnings("serial")
public class DataConsentReview extends AbstractBeanRelationsAttributes implements java.io.Serializable {

    /** DataConsentReview attributes enumeration */
    public static class Fields {
        /** id column */
        public static final String ID = "id";
        /** lastReviewDate column */
        public static final String LASTREVIEWDATE = "lastReviewDate";

	    /**
          * List of existing fields
	     *
	     * @return list of field names
	     */
        public static List<String> values() {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("lastReviewDate");

            return list;
        }
    }

	/**
 	 * The Class Relations.
 	 */
	 public class Relations extends AbstractBeanRelationsAttributes.AbstractRelations {

        /**
         * Instantiates a new relations.
         *
         * @param currentPath
         *            the current path
         */
        public Relations(String currentPath)
        {
            super(currentPath);
        }
        /**
         * dataConsent relation.
         *
         * @return the dataConsent bean relations attributes.
         */
        public DataConsent.Relations dataConsent()
        {
			DataConsent c = new DataConsent();
            return c.new Relations(this.buildPath("dataConsent"));
        }
        
        /**
         * dataConsentUser relation.
         *
         * @return the dataConsentUser bean relations attributes.
         */
        public DataConsentUser.Relations dataConsentUser()
        {
			DataConsentUser c = new DataConsentUser();
            return c.new Relations(this.buildPath("dataConsentUser"));
        }
        
		/**
         * the ID path.
         *
         * @return the path
         */
        public String ID()
        {
            return buildPath(Fields.ID);
        }
		/**
         * the LASTREVIEWDATE path.
         *
         * @return the path
         */
        public String LASTREVIEWDATE()
        {
            return buildPath(Fields.LASTREVIEWDATE);
        }
    }
	
	/** The dummy obj. */
    private static DataConsentReview dummyObj = new DataConsentReview();

	/**
     * Get DataConsentReview Relations .
     *
     * @return the relations
     */
    public static Relations FK()
    {
        return dummyObj.new Relations(null);
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
     */
    @Override
    protected Object getAttributeNoGraphNavigation(String attributeName) {

        if ("id".equalsIgnoreCase(attributeName))
            return id;
        if ("dataConsent".equalsIgnoreCase(attributeName))
            return dataConsent;
        if ("dataConsentUser".equalsIgnoreCase(attributeName))
            return dataConsentUser;
        if ("lastReviewDate".equalsIgnoreCase(attributeName))
            return lastReviewDate;

        return null;
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
     */
    @SuppressWarnings("all")
    public void setAttribute(String attributeName, Object attributeValue) {

        if ("id".equalsIgnoreCase(attributeName))
            id = (Long)attributeValue;
        if ("dataConsent".equalsIgnoreCase(attributeName))
            dataConsent = (DataConsent)attributeValue;
        if ("dataConsentUser".equalsIgnoreCase(attributeName))
            dataConsentUser = (DataConsentUser)attributeValue;
        if ("lastReviewDate".equalsIgnoreCase(attributeName))
            lastReviewDate = (Timestamp)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** dataConsent private attribute */
    private DataConsent dataConsent;

    /** dataConsentUser private attribute */
    private DataConsentUser dataConsentUser;

    /** lastReviewDate private attribute */
    private Timestamp lastReviewDate;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else {
            return value.toString().trim();
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public DataConsentReview() {
    }

	/** 
	 * minimal constructor
	 *
     * @param dataConsent
     * @param lastReviewDate
    }
	 */
    public DataConsentReview(DataConsent dataConsent, Timestamp lastReviewDate) {
        this.dataConsent = dataConsent;
        this.lastReviewDate = lastReviewDate;
    }

    /**
     * full constructor
	 *
     * @param dataConsent
     * @param dataConsentUser
     * @param lastReviewDate
     */
    public DataConsentReview(DataConsent dataConsent, DataConsentUser dataConsentUser, Timestamp lastReviewDate) {
        this.dataConsent = dataConsent;
        this.dataConsentUser = dataConsentUser;
        this.lastReviewDate = lastReviewDate;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id
     *
     * @return DataConsentReview modified instance
     */
    public DataConsentReview setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * dataConsent getter method
     *
     * @return dataConsent method
     */
    public DataConsent getDataConsent() {
        return this.dataConsent;
    }
    
    /**       
     * dataConsent setter method
     *
     * @param dataConsent
     *
     * @return DataConsentReview modified instance
     */
    public DataConsentReview setDataConsent(DataConsent dataConsent) {
        this.dataConsent = dataConsent;
        
        return this;
    }
    /**       
     * dataConsentUser getter method
     *
     * @return dataConsentUser method
     */
    public DataConsentUser getDataConsentUser() {
        return this.dataConsentUser;
    }
    
    /**       
     * dataConsentUser setter method
     *
     * @param dataConsentUser
     *
     * @return DataConsentReview modified instance
     */
    public DataConsentReview setDataConsentUser(DataConsentUser dataConsentUser) {
        this.dataConsentUser = dataConsentUser;
        
        return this;
    }
    /**       
     * lastReviewDate getter method
     *
     * @return lastReviewDate method
     */
    public Timestamp getLastReviewDate() {
        return this.lastReviewDate;
    }
    
    /**       
     * lastReviewDate setter method
     *
     * @param lastReviewDate
     *
     * @return DataConsentReview modified instance
     */
    public DataConsentReview setLastReviewDate(Timestamp lastReviewDate) {
        this.lastReviewDate = lastReviewDate;
        
        return this;
    }

    /**
     * Creates a String representation of the DataConsentReview object
     *
     * @return the compiled String
     */
    @Override
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("lastReviewDate").append("='").append(getLastReviewDate()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the DataConsentReview object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(DataConsentReview other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("lastReviewDate".equalsIgnoreCase(attributeName))
            this.lastReviewDate = Timestamp.valueOf(attributeValue);

    }


}
